package chart;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletResponse;
import java.io.OutputStream;
import com.aspose.cells.Style;
import com.aspose.cells.*;
import com.aspose.cells.Chart;
import javax.servlet.ServletContext;

public class ConePercentStackedServlet extends HttpServlet {

  private static final String TEMPLATE_FILE_PATH_PART = "/WEB-INF/Designer/Chart/PercentStacked.xls";

public void doGet(HttpServletRequest request, HttpServletResponse response)
throws IOException, ServletException
{
OutputStream out = response.getOutputStream();
try
{
  ServletContext sc = getServletContext();
  String template_file_path = sc.getRealPath(TEMPLATE_FILE_PATH_PART);

  setResponseHeader(response, "ConePercentStacked.xls");
  int chartType = Integer.parseInt(request.getParameter("ChartTypeList"));
  CreateConeChart(out, template_file_path, chartType);
}
catch (Exception ex)
{
  ex.printStackTrace();

  // say sorry
  response.setContentType("text/html");
  PrintWriter writer = new PrintWriter(out);

  writer.println("<html>");
  writer.println("<head>");
  writer.println("<title>sorry</title>");
  writer.println("</head>");
  writer.println("<body>");
  writer.println("<h1>Sorry, the demo programme failed for some reason.</h1>");
  ex.printStackTrace(writer);
  writer.println("</body>");
  writer.println("</html>");
  writer.close();
}
}

public void doPost(HttpServletRequest request, HttpServletResponse response)
   throws IOException, ServletException
{
doGet(request, response);
}

private void setResponseHeader(HttpServletResponse response, String resultXLS)
{
response.setContentType("application/vnd.ms-excel");
response.addHeader("content-disposition", "inline;  filename=" + resultXLS);
}

private void CreateConeChart(OutputStream out,String template_file_path, int chartType) throws IOException
{
Workbook workbook = new Workbook();

workbook.open(template_file_path);
CreateStaticReport(workbook, chartType);

workbook.save(out);
}

  private void CreateStaticReport(Workbook workbook, int chartType)
  {
    Worksheets worksheets = workbook.getWorksheets();
    Worksheet dataSheet = worksheets.getSheet(0);
    Worksheet worksheet = worksheets.addSheet(SheetType.CHART);
    //Set the name of worksheet
    dataSheet.setName("Data");
    worksheet.setName("Chart");

    Charts charts = worksheet.getCharts();
    int chartIndex = 0;
    switch (chartType)
    {
      case 0:
        chartIndex = charts.add(ChartType.CONE_100PERCENT_STACKED, 0, 0, 0, 0);
        break;
      case 1:
        chartIndex = charts.add(ChartType.CONICAL_BAR_100PERCENT_STACKED, 0, 0, 0, 0);
        break;
    }
    Chart chart = charts.getChart(chartIndex);

    //Add the nseries collection to a chart
    NSeries nSeries = chart.getNSeries();
    nSeries.add("Data!B2:E4", false);
    nSeries.setCategoryData("Data!B1:E1");

    Cells cells = dataSheet.getCells();
    String temp;
    for (int i = 0; i < nSeries.size(); i ++)
    {
      temp = cells.getCell(i + 1, 0).getStringValue();
      nSeries.get(i).setName(temp);
    }

    //Set properies to title
    Title title = chart.getTitle();
    title.setText("Product contribution to total sales");
    Font font = new Font();
    font.setBold(true);
    font.setColor(Color.BLACK);
    font.setSize(12);
    title.setFont(font);
  }
}
