package chart;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletResponse;
import java.io.OutputStream;
import com.aspose.cells.Style;
import com.aspose.cells.*;
import com.aspose.cells.Chart;
import javax.servlet.ServletContext;

public class ContourServlet extends HttpServlet {
  public ContourServlet() {
    try {
      jbInit();
    }
    catch (Exception ex) {
      ex.printStackTrace();
    }
  }

  private static final String TEMPLATE_FILE_PATH_PART = "/WEB-INF/Designer/Chart/SurfaceTemplate.xls";

 public void doGet(HttpServletRequest request, HttpServletResponse response)
throws IOException, ServletException
{
OutputStream out = response.getOutputStream();
try
{
   ServletContext sc = getServletContext();
   String template_file_path = sc.getRealPath(TEMPLATE_FILE_PATH_PART);

   setResponseHeader(response, "Contour.xls");
   int chartType = Integer.parseInt(request.getParameter("ChartTypeList"));
   CreateSurfaceChart(out, template_file_path, chartType);
}
catch (Exception ex)
{
   ex.printStackTrace();

   // say sorry
   response.setContentType("text/html");
   PrintWriter writer = new PrintWriter(out);

   writer.println("<html>");
   writer.println("<head>");
   writer.println("<title>sorry</title>");
   writer.println("</head>");
   writer.println("<body>");
   writer.println("<h1>Sorry, the demo programme failed for some reason.</h1>");
   ex.printStackTrace(writer);
   writer.println("</body>");
   writer.println("</html>");
   writer.close();
}
}

public void doPost(HttpServletRequest request, HttpServletResponse response)
    throws IOException, ServletException
{
 doGet(request, response);
}

private void setResponseHeader(HttpServletResponse response, String resultXLS)
{
response.setContentType("application/vnd.ms-excel");
response.addHeader("content-disposition", "inline;  filename=" + resultXLS);
}

private void CreateSurfaceChart(OutputStream out,String template_file_path, int chartType) throws IOException
{
Workbook workbook = new Workbook();

workbook.open(template_file_path);
CreateStaticReport(workbook, chartType);

workbook.save(out);
}

 private void CreateStaticReport(Workbook workbook, int chartType)
 {
   Worksheets worksheets = workbook.getWorksheets();
   Worksheet dataSheet = worksheets.getSheet(0);
   Worksheet worksheet = worksheets.addSheet();
   //Set the name of worksheet
   dataSheet.setName("Data");
   worksheet.setName("Chart");

   //Create chart
   Charts charts = worksheet.getCharts();
   int chartIndex = 0;
   switch (chartType)
   {
      case 0:
        chartIndex = charts.add(ChartType.SURFACE_CONTOUR, 1, 1, 25, 10);
       break;
      case 1:
        chartIndex = charts.add(ChartType.SURFACE_CONTOUR_WIREFRAME, 1, 1, 25, 10);
        break;
   }
   Chart chart = charts.getChart(chartIndex);

   //Set properties of nseries
   NSeries nSeries = chart.getNSeries();
   nSeries.add("Data!B3:F11", true);
   nSeries.setCategoryData("Data!A3:A11");

   Cells cells = dataSheet.getCells();
   String temp = "";
   for (int i = 0; i < nSeries.size(); i ++)
   {
     temp = cells.getCell(0, i + 1).getStringValue();
     nSeries.get(i).setName(temp);
   }

   //Set properties of chart title
   Title title = chart.getTitle();
   title.setText("Tensile strenth Measurements");
   Font font1 = new Font();
   font1.setBold(true);
   font1.setColor(Color.BLACK);
   font1.setSize(12);
   title.setFont(font1);

   //Set properties of categoryaxis title
   CategoryAxis categoryAxis = chart.getCategoryAxis();
   categoryAxis.getTitle().setText("Seconds");
   Font font2 = new Font();
   font2.setBold(true);
   font2.setColor(Color.BLACK);
   font2.setSize(10);
   categoryAxis.getTitle().setFont(font2);
 }

  private void jbInit() throws Exception {
  }
}
