package chart;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;
import java.util.*;
import java.sql.SQLException;
import com.aspose.cells.*;
import com.aspose.cells.Chart;

public class StackedColumnServlet  extends HttpServlet {

  private static final String TEMPLATE_FILE_PATH_PART = "/WEB-INF/Designer/Chart/StackedColumn.xls";

  public void doGet(HttpServletRequest request, HttpServletResponse response) throws
      IOException, ServletException {
    OutputStream out = response.getOutputStream();
    try {

      ServletContext sc = getServletContext();
      String template_file_path = sc.getRealPath(TEMPLATE_FILE_PATH_PART);

      String parameter = request.getParameter("checkBoxShow3D");
      setResponseHeader(response, "StackedColumn.xls");
      CreateColumnChart(out, template_file_path, parameter);
    }
    catch (Exception ex) {
      ex.printStackTrace();

      // say sorry
      response.setContentType("text/html");
      PrintWriter writer = new PrintWriter(out);

      writer.println("<html>");
      writer.println("<head>");
      writer.println("<title>sorry</title>");
      writer.println("</head>");
      writer.println("<body>");
      writer.println(
          "<h1>Sorry, the demo programme failed for some reason.</h1>");
      ex.printStackTrace(writer);
      writer.println("</body>");
      writer.println("</html>");
      writer.close();
    }
  }

  public void doPost(HttpServletRequest request, HttpServletResponse response) throws
      IOException, ServletException {
    doGet(request, response);
  }

  private void setResponseHeader(HttpServletResponse response, String resultXLS) {
    response.setContentType("application/vnd.ms-excel");
    response.addHeader("content-disposition", "inline;  filename=" + resultXLS);
  }

  private void CreateColumnChart(OutputStream out, String template_file_path, String Parameter) throws
      IOException {
    Workbook workbook = new Workbook();

    workbook.open(template_file_path);

    CreateStaticReport(workbook, Parameter);

    workbook.save(out);
  }

  private void CreateStaticReport(Workbook workbook, String Parameter)
  {
    Worksheets worksheets = workbook.getWorksheets();
    Worksheet worksheet = worksheets.addSheet();
    Worksheet dataSheet = worksheets.getSheet(0);
    //Set the name of worksheet
    dataSheet.setName("Data");
    worksheet.setName("Chart");

    //Create chart
    Charts charts = worksheet.getCharts();
    int chartIndex = 0;
    //Show as 2d or 3d
    if (Parameter != null)
      chartIndex = charts.add(ChartType.COLUMN_3D_STACKED, 1, 1, 25, 10);
    else
      chartIndex = charts.add(ChartType.COLUMN_STACKED, 1, 1, 25, 10);
    Chart chart = charts.getChart(chartIndex);

    //Set properies to chart
    if (Parameter != null)
      chart.getPlotArea().getBorder().setVisible(false);

    //Set properies to chart title
    Title title = chart.getTitle();
    title.setText("Product  Sales");
    Font font1 = new Font();
    font1.setColor(Color.BLACK);
    font1.setBold(true);
    font1.setSize(12);
    title.setFont(font1);

    //Set properies to nseries
    NSeries nSeries = chart.getNSeries();
    nSeries.setCategoryData("Data!A2:A4");
    nSeries.add("Data!B2:C4", true);

    Cells cells = dataSheet.getCells();
    String temp = "";
    for (int i = 0; i < nSeries.size(); i ++)
    {
      temp = cells.getCell(0, i + 1).getStringValue();
      nSeries.get(i).setName(temp);
    }

    //Set properies to categoryaxis
    CategoryAxis categoryAxis = chart.getCategoryAxis();
    categoryAxis.getTitle().setText("Year(2004-2006)");
    Font font2 = new Font();
    font2.setColor(Color.BLACK);
    font2.setBold(true);
    font2.setSize(10);
    categoryAxis.getTitle().setFont(font2);

    //Set the legend position type
    chart.getLegend().setPosition(LegendPositionType.TOP);
  }

}



